Module test_data

Module test_data 

Rust custom data types used for catalog roundtrip testing.

Exposed to Python via the persistence PyO3 module so Python tests can exercise custom data write/query roundtrips.

Structs

MacroYieldCurveData
YieldCurveData-equivalent custom data type using the macro with Vec<f64> fields.
RustTestCustomData
A simple Rust custom data type for roundtrip testing.
RustTestParamsCustomData
Rust custom data type that exercises Params field support in the macro.