Rust custom data types used for catalog roundtrip testing.
Exposed to Python via the persistence PyO3 module so Python tests can exercise custom data write/query roundtrips.
Structs
- Macro
Yield Curve Data - YieldCurveData-equivalent custom data type using the macro with
Vec<f64>fields. - Rust
Test Custom Data - A simple Rust custom data type for roundtrip testing.
- Rust
Test Params Custom Data - Rust custom data type that exercises
Paramsfield support in the macro.